{
    "scan": {
        "analyzer-version-clippy": "1.95.0",
        "analyzer-version-cppcheck": "2.20.0",
        "analyzer-version-gcc": "16.1.1",
        "analyzer-version-gcc-analyzer": "16.1.1",
        "analyzer-version-shellcheck": "0.11.0",
        "analyzer-version-unicontrol": "0.0.2",
        "enabled-plugins": "clippy, cppcheck, gcc, shellcheck, unicontrol",
        "exit-code": 0,
        "host": "ip-172-16-1-221.us-west-2.compute.internal",
        "known-false-positives": "/usr/share/csmock/known-false-positives.js",
        "known-false-positives-rpm": "known-false-positives-0.0.0.20260524.213755.g3c6d0be.main-1.el9.noarch",
        "mock-config": "fedora-rawhide-x86_64",
        "project-name": "python-lxml-6.0.2-2.fc44",
        "store-results-to": "/tmp/tmpfcuk4bms/python-lxml-6.0.2-2.fc44.tar.xz",
        "time-created": "2026-06-01 16:06:17",
        "time-finished": "2026-06-01 16:11:31",
        "tool": "csmock",
        "tool-args": "'/usr/bin/csmock' '-r' 'fedora-rawhide-x86_64' '-t' 'shellcheck,cppcheck,clippy,unicontrol,gcc' '-o' '/tmp/tmpfcuk4bms/python-lxml-6.0.2-2.fc44.tar.xz' '--gcc-analyze' '--unicontrol-notests' '--unicontrol-bidi-only' '--install' 'pam' '--gcc-analyzer-bin=/usr/bin/gcc' '/tmp/tmpfcuk4bms/python-lxml-6.0.2-2.fc44.src.rpm'",
        "tool-version": "csmock-3.8.5.20260529.133039.g6f3b5c6-1.el9"
    },
    "defects": [
        {
            "checker": "CPPCHECK_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "cppcheck",
            "hash_v1": "2d6e79a0cdcca999539051bc1f8c13044735fdd4",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "lxml-6.0.2/src/lxml/_elementpath.c",
                    "line": 22393,
                    "event": "warning[nullPointer]",
                    "message": "Possible null pointer dereference: pvalue",
                    "verbosity_level": 0
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "22391|           *pkey = next_item;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "22392|       } else {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "22393|->         *pvalue = next_item;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "22394|       }",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "22395|       return 1;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "COMPILER_WARNING",
            "language": "c/c++",
            "tool": "gcc",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "lxml-6.0.2/src/lxml/etree.c",
                    "line": 0,
                    "event": "internal warning",
                    "message": "child 92 timed out after 30s",
                    "verbosity_level": 0
                }
            ]
        },
        {
            "checker": "COMPILER_WARNING",
            "language": "c/c++",
            "tool": "gcc",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "lxml-6.0.2/src/lxml/html/_difflib.c",
                    "line": 0,
                    "event": "internal warning",
                    "message": "child 466 timed out after 30s",
                    "verbosity_level": 0
                }
            ]
        },
        {
            "checker": "CPPCHECK_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "cppcheck",
            "hash_v1": "865ea11cbe59085480c126be8fd05a89b664f3ff",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "lxml-6.0.2/src/lxml/html/_difflib.c",
                    "line": 43719,
                    "event": "warning[nullPointer]",
                    "message": "Possible null pointer dereference: pvalue",
                    "verbosity_level": 0
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "43717|           *pkey = next_item;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "43718|       } else {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "43719|->         *pvalue = next_item;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "43720|       }",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "43721|       return 1;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "COMPILER_WARNING",
            "language": "c/c++",
            "tool": "gcc",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "lxml-6.0.2/src/lxml/html/diff.c",
                    "line": 0,
                    "event": "internal warning",
                    "message": "child 412 timed out after 30s",
                    "verbosity_level": 0
                }
            ]
        },
        {
            "checker": "COMPILER_WARNING",
            "cwe": 704,
            "language": "c/c++",
            "tool": "gcc",
            "hash_v1": "83bb302a3d04f43bfd3d2233b9f355906511aee2",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "lxml-6.0.2/src/lxml/objectify.c",
                    "line": 4901,
                    "column": 13,
                    "h_size": 1,
                    "event": "warning[-Wdiscarded-qualifiers]",
                    "message": "assignment discards ‘const’ qualifier from pointer target type",
                    "verbosity_level": 0
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 4899|    *         c_name = s + 1",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 4900|   */",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 4901|->   __pyx_v_s = strrchr(__pyx_v_c_name, '.');",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 4902|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 4903|     /* \"lxml/objectify.pyx\":54",
                    "verbosity_level": 1
                }
            ]
        }
    ]
}
