{
    "defects": [
        {
            "checker": "COMPILER_WARNING",
            "language": "c/c++",
            "tool": "gcc",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/python-lxml-6.0.2-build/lxml-6.0.2/src/lxml/etree.c",
                    "line": 0,
                    "event": "internal warning",
                    "message": "child 92 timed out after 30s",
                    "verbosity_level": 0
                }
            ]
        },
        {
            "checker": "CPPCHECK_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "cppcheck",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/python-lxml-6.0.2-build/lxml-6.0.2/src/lxml/_elementpath.c",
                    "line": 22393,
                    "event": "warning[nullPointer]",
                    "message": "Possible null pointer dereference: pvalue",
                    "verbosity_level": 0
                }
            ]
        },
        {
            "checker": "COMPILER_WARNING",
            "language": "c/c++",
            "tool": "gcc",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/python-lxml-6.0.2-build/lxml-6.0.2/src/lxml/html/diff.c",
                    "line": 0,
                    "event": "internal warning",
                    "message": "child 412 timed out after 30s",
                    "verbosity_level": 0
                }
            ]
        },
        {
            "checker": "CPPCHECK_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "cppcheck",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/python-lxml-6.0.2-build/lxml-6.0.2/src/lxml/html/_difflib.c",
                    "line": 43719,
                    "event": "warning[nullPointer]",
                    "message": "Possible null pointer dereference: pvalue",
                    "verbosity_level": 0
                }
            ]
        },
        {
            "checker": "COMPILER_WARNING",
            "language": "c/c++",
            "tool": "gcc",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/python-lxml-6.0.2-build/lxml-6.0.2/src/lxml/html/_difflib.c",
                    "line": 0,
                    "event": "internal warning",
                    "message": "child 466 timed out after 30s",
                    "verbosity_level": 0
                }
            ]
        }
    ]
}
